<?php
namespace EMS\PortalFuncionario\Geral\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;

use EMS\PortalFuncionario\Geral\Services\OperadorService;

class OperadorController {
    /** @var OperadorService */
    protected $operadorService;

    public function __construct(EntityManager $entityManager, OperadorService $operadorService) {
        $this->entityManager    = $entityManager;
        $this->operadorService  = $operadorService;
    }

    public function getDadosOperador(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $dadosOperador = $this->operadorService->getDadosOperador(
                $params['CDOPERADOR'],
                $params['DTNASCPESSOA']     ?? null,
                $params['DTADMISSAOVINC']   ?? null,
                $params['NRCPFPESSOA']      ?? null
            );
            $response->addDataSet(new DataSet('getDadosOperador', $dadosOperador));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function validaLoginVinculo(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $validaLogin = $this->operadorService->validaLogin(
                $params['NRVINCULOM'],
                $params['NRORG']
            );
            $response->addDataSet(new DataSet('validaLogin', array($validaLogin)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function validaLoginOperador(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $validaLoginOperador = $this->operadorService->validaLoginOperador(
                $params['CDOPERADOR'],
                $params['DTNASCPESSOA']     ?? null,
                $params['DTADMISSAOVINC']   ?? null,
                $params['NRCPFPESSOA']      ?? null
            );
            $response->addDataSet(new DataSet('validaLoginOperador', array($validaLoginOperador)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getBeforeForgotPasswordInfo(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $validaLoginOperador = $this->operadorService->getBeforeForgotPasswordInfo(
                $params['DSEMAILOPER'] ?? ''
            );
            $response->addDataSet(new DataSet('getBeforeForgotPasswordInfo', array($validaLoginOperador)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function confirmationChangePassword(
        DTO\Request\Row $request,
        DTO\Response    $response
    ) {
        try {
            $row = (array) $request->getRow()->getArrayCopy();

            $success = $this->operadorService->confirmationChangePassword(
                $row['NRORG'],
                $row['EMAIL'],
                $row['CDOPERADOR'],
                $row['DTNASCIMENTO'],
                $row['DTADMISSAO'],
                $row['CPF'],
                $row['NEW_PASSWORD'],
                $row['CONFIRM_NEW_PASSWORD']
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('confirmationChangePassword', $dataset));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function validatePassword(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];
            $cdOperador = (string) $row['CDOPERADOR'];
            $password = (string) $row['PASSWORD'];

            $isValid = $this->operadorService->validatePassword(
                $nrOrg, $cdOperador, $password
            );

            $dataset = [
                'isValid' => $isValid,
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

}