<?php

namespace EMS\PortalFuncionario\Geral\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class EscalaRepository {
    
    /** @var Connection */
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    public function getEscalaTrabalhoVinculo(
        int  $nrOrg,
        int  $nrVinculom,
        bool $throwException = false
    ) {

        $sql = <<<SQL
            SELECT
                ESCM.*,
                ESCH.*
            FROM
                GPE_VINCULOM      VM
                JOIN GPE_VINCULOH      VH ON VH.NRORG = VM.NRORG
                                        AND VH.NRVINCULOM = VM.NRVINCULOM
                                        AND VH.DTMESCOMPETENC = (
                    SELECT
                        MAX(VHH.DTMESCOMPETENC)
                    FROM
                        GPE_VINCULOH VHH
                    WHERE
                        VHH.NRORG = VH.NRORG
                        AND VHH.NRVINCULOM = VH.NRVINCULOM
                )
                JOIN GPE_ESCALATRABM   ESCM ON ESCM.NRORG = VM.NRORG
                                             AND ESCM.NRESCALATRABM = VH.NRESCALATRABM
                JOIN GPE_ESCALATRABH   ESCH ON ESCH.NRORG = ESCM.NRORG
                                             AND ESCH.NRESCALATRABM = ESCM.NRESCALATRABM
                                             AND ESCH.DTMESCOMPETENC = (
                    SELECT
                        MAX(ESCHH.DTMESCOMPETENC)
                    FROM
                        GPE_ESCALATRABH ESCHH
                    WHERE
                        ESCHH.NRORG = ESCH.NRORG
                        AND ESCHH.NRESCALATRABM = ESCH.NRESCALATRABM
                )
            WHERE
                VM.NRORG = :P_NRORG
                AND VM.NRVINCULOM = :P_NRVINCULOM
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRVINCULOM' => $nrVinculom,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $marcacao = $std->fetch();

        if ($throwException && !$marcacao) {
            throw new \Exception('Escala do vínculo não encontrada!');
        }

        return $marcacao;
    }

    public function getEscalaTrab(
        array $params
    ): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GPE_ESCALATRABM ETM
                JOIN
                GPE_ESCALATRABH ETH ON
                    ETM.NRORG = ETH.NRORG AND
                    ETM.NRESCALATRABM = ETH.NRESCALATRABM AND
                    ETH.DTMESCOMPETENC = (
                        SELECT
                            MAX(DTMESCOMPETENC)
                        FROM
                            GPE_ESCALATRABH
                        WHERE
                            NRORG = ETH.NRORG AND
                            NRESCALATRABM = ETH.NRESCALATRABM AND
                            DTMESCOMPETENC <= :P_DTMESCOMPETENC
                    )
                LEFT JOIN
                PTO_TIPOJORNADA TJ ON
                    (
                        TJ.NRORG = :P_NRORG OR
                        TJ.NRORG = :P_NRORG_PADRAO
                    ) AND
                    ETH.NRTPJORNADA = TJ.NRTPJORNADA
                LEFT JOIN
                PTO_TIPOINTERVALO TI ON
                    (
                        TI.NRORG = :P_NRORG OR
                        TI.NRORG = :P_NRORG_PADRAO
                    ) AND
                    ETH.NRTPINTERVALO = TI.NRTPINTERVALO
            WHERE
                (
                    ETM.NRORG = :P_NRORG OR
                    ETM.NRORG = :P_NRORG_PADRAO
                ) AND
                ETH.IDATIVO = 'S'
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $escalas = $std->fetchAll();

        return $escalas;
    }

    public function getTurnos(
        array $params
    ): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GPE_TURNO
            WHERE
                NRESCALATRABM = :P_NRESCALATRABM AND
                NRORG = :P_NRORG AND
                IDATIVO = 'S'
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $turnos = $std->fetchAll();

        return $turnos;
    }
}