<?php
namespace EMS\PortalFuncionario\Geral\Services;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;

use EMS\PortalFuncionario\Geral\Repository\HistoricoRepository;

class HistoricoService extends Crud {

	public function __construct(EntityManager $entityManager, HistoricoRepository $historicoRepository) {
		$this->entityManager        = $entityManager;
		$this->historicoRepository  = $historicoRepository;
	}

	public function getMarcacoes(string $nrorg, string $nrvinculom, string $dtinicialapuracao, string $dtfinalapuracao = null) : array {
		try {
			$historico = $this->historicoRepository->getMarcacoes(
				$nrorg,
				$nrvinculom,
				$dtinicialapuracao,
				$dtfinalapuracao
			);

			foreach ($historico as &$marcacao) {
				$marcacao['COLETOR_GESTOR'] = $marcacao['COLETOR_GESTOR'] === 'S';
				$marcacao['COLETOR_FUNC'] 	= $marcacao['COLETOR_FUNC'] === 'S';
			}

			return $historico;
		} catch (\Exception $e) {
			throw $e;
		}
	}

	public function getQuantidadeMarcacoes(string $nrorg, string $nrvinculom, string $dtinicialapuracao, string $dtfinalapuracao = null) : int {
		try {
			return count($this->historicoRepository->getMarcacoes($nrorg, $nrvinculom, $dtinicialapuracao, $dtfinalapuracao));
		} catch (\Exception $e) {
			throw $e;
		}
	}

	public function getUltimaMarcacao(string $nrorg, string $nrvinculom) : array {
		try {
			$marcacoes = $this->historicoRepository->getMarcacoes($nrorg, $nrvinculom);

			if (empty($marcacoes)) {
				return [];
			}

			$ultimaMarcacao = $marcacoes[0];

			$dataUltimaMarcacao = $ultimaMarcacao['DTMARCACAOPONTO'];

			$dataAtual = new \DateTime();
			$diaAtual = $dataAtual->format('d/m/Y');

			$dataAnterior = new \DateTime();
			$dataAnterior->setTimestamp(strtotime('-1 day'));
			$diaAnterior = $dataAnterior->format('d/m/Y');

			if ($dataUltimaMarcacao === $diaAtual) {
				$ultimaMarcacao['TEMPORELATIVO'] = 'Hoje';
			} else if ($dataUltimaMarcacao === $diaAnterior) {
				$ultimaMarcacao['TEMPORELATIVO'] = 'Ontem';
			} else {
				$ultimaMarcacao['TEMPORELATIVO'] = $ultimaMarcacao['DTMARCACAOPONTO'];
			}

			return $ultimaMarcacao;
		} catch (\Exception $e) {
			throw $e;
		}
	}

}